==> testwise-6.15-linux64.tar.gz: testwise-6.15/samples/demo-webapp-raw/spec/03_passenger_spec.rb <==
load File.dirname(__FILE__) + "/../test_helper.rb"

describe "Passenger" do
  include TestHelper

  before(:all) do
    @driver = $driver = Selenium::WebDriver.for(browser_type, browser_options)
    driver.manage().window().resize_to(1024, 700)
    driver.manage().window().move_to(30, 78)
    driver.get(site_url)

    driver.find_element(:id, "username").send_keys("agileway")
    driver.find_element(:id, "password").send_keys("testwise")
    driver.find_element(:id, "username").submit
  end

  after(:all) do
    fail_safe { driver.find_element(:link_text, "Sign off").click } unless debugging?
    driver.quit unless debugging?
  end

  it "[4] Can enter passenger details (using page objects)" do
    driver.find_element(:xpath, "//input[@name='tripType' and @value='return']").click
    Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "fromPort")).select_by(:text, "Sydney")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "toPort")).select_by(:text, "New York")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "departDay")).select_by(:text, "02")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "departMonth")).select_by(:text, "May #{Date.today.year}")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "returnDay")).select_by(:text, "04")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "returnMonth")).select_by(:text, "June #{Date.today.year}")
    driver.find_element(:xpath, "//input[@value='Continue']").click

    # now on passenger page
    driver.find_element(:name, "passengerFirstName").send_keys("Bob")
    driver.find_element(:name, "passengerLastName").submit # submit the form, ie click 'Next'

    try_for(3) { expect(driver.page_source).to include("Must provide last name") }
    driver.find_element(:name, "passengerFirstName").send_keys("Bob")
    driver.find_element(:name, "passengerLastName").send_keys("Tester")
    driver.find_element(:name, "passengerLastName").submit

    expect(driver.find_element(:name, "holder_name").attribute("value")).to eq("Bob Tester")
  end
end

==> testwise-7.1.3-linux64.tar.gz: testwise-7.1.3/samples/demo-webapp-raw/spec/03_passenger_spec.rb <==
load File.dirname(__FILE__) + "/../test_helper.rb"

describe "Passenger" do
  include TestHelper

  before(:all) do
    @driver = $driver = Selenium::WebDriver.for(browser_type, browser_options)
    driver.manage().window().resize_to(1024, 700)
    driver.manage().window().move_to(30, 78)
    driver.get(site_url)

    driver.find_element(:id, "username").send_keys("agileway")
    driver.find_element(:id, "password").send_keys("testwise")
    driver.find_element(:id, "username").submit
  end

  after(:all) do
    fail_safe { driver.find_element(:partial_link_text, "Sign off").click } unless debugging?
    driver.quit unless debugging?
  end

  it "[4] Can enter passenger details (using page objects)" do
    driver.find_element(:xpath, "//input[@name='tripType' and @value='return']").click
    Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "fromPort")).select_by(:text, "Sydney")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "toPort")).select_by(:text, "New York")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "departDay")).select_by(:text, "02")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "departMonth")).select_by(:text, "May #{Date.today.year}")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "returnDay")).select_by(:text, "04")
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "returnMonth")).select_by(:text, "June #{Date.today.year}")
    driver.find_element(:xpath, "//input[@value='Continue']").click

    # now on passenger page
    driver.find_element(:name, "passengerFirstName").send_keys("Bob")
    driver.find_element(:name, "passengerLastName").submit # submit the form, ie click 'Next'

    try_for(3) { expect(driver.page_source).to include("Must provide last name") }
    driver.find_element(:name, "passengerFirstName").send_keys("Bob")
    driver.find_element(:name, "passengerLastName").send_keys("Tester")
    driver.find_element(:name, "passengerLastName").submit

    expect(driver.find_element(:name, "holder_name").attribute("value")).to eq("Bob Tester")
  end
end
